@@ -1,4 +1,4 @@
-from django.conf.urls import url
+from django.urls import re_path as url
 from wiki.core.plugins import registry
 from wiki.core.plugins.base import BasePlugin
 from wiki.plugins.editsection.markdown_extensions import EditSectionExtension
