@@ -1,4 +1,5 @@
-from django.db import migrations, models
+from django.db import migrations
+from django.db import models
 
 
 class Migration(migrations.Migration):
@@ -11,6 +12,7 @@ class Migration(migrations.Migration):
 
     operations = [
         migrations.AlterModelTable(
-            name="articlesubscription", table="wiki_notifications_articlesubscription",
+            name="articlesubscription",
+            table="wiki_notifications_articlesubscription",
         ),
     ]
